.. Mia! Accounting documentation master file, created by
   sphinx-quickstart on Fri Jan 27 12:20:04 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Mia! Accounting's documentation!
===========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   accounting
   examples
   history
   changelog



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
